=======
Falcone
=======

.. image:: https://travis-ci.org/dgarana/falcone.svg?branch=master
    :align: center
    :alt: Build status
    :target: https://travis-ci.org/dgarana/falcone

.. image:: https://api.codacy.com/project/badge/Grade/d1c039e4d000418087702427a88d9b4a    
    :align: center
    :alt: Code check
    :target: https://www.codacy.com/app/david-gp87/falcone
 
The Python Falcon framework extender.
